Name:           tkimg
Version:        1.4.14
Release:        %mkrel 2
Summary:        Image support library for Tk
Group:          System/Libraries
License:        BSD
URL:            https://sourceforge.net/projects/tkimg
Source0:        https://downloads.sourceforge.net/project/tkimg/tkimg/1.4/Img-%{version}-Source.tar.gz
# Apply upstream libtiff fix for CVE-2022-4645
# I do not think it impacts tkimg, but better safe than sorry.
# https://gitlab.com/libtiff/libtiff/-/commit/e813112545942107551433d61afd16ac094ff246
Patch0:         tkimg-libtiff-CVE-2022-4645.patch

BuildRequires:  pkgconfig(tcl)
BuildRequires:  pkgconfig(tk)
BuildRequires:  tcl-tcllib
Requires:       tcl

# tkimg builds its own bundled copies of the zlib, libjpeg, libpng,
# and libtiff libraries. From the README:
#  Note that you have to build these libraries to
#  support the named formats, even if your system already has shared
#  libraries for these formats. This is because the libraries here are
#  built such that they can be loaded as packages by the Tcl/Tk core,
#  making the handling of the various dependencies much easier. An
#  earlier version, 1.2.4, used a modified copy of Tcl's functions for
#  loading of shared libraries to load the support libraries at runtime.
#  These have been abandoned in favor of the new approach.

Provides:       bundled(zlib) = 1.2.13
Provides:       bundled(libjpeg) = 9e
Provides:       bundled(libpng) = 1.6.38
Provides:       bundled(libtiff) = 4.4.0

%description
This package contains a collection of image format handlers for the Tk
photo image type, and a new image type, pixmaps.
The provided format handlers include bmp, gif, ico, jpeg, pcx, png,
ppm, ps, sgi, sun, tga, tiff, xbm, and xpm.

%package devel
Summary:        Libraries, includes, etc. used to develop an application with %{name}
Group:          System/Libraries
Requires:       %{name} = %{version}-%{release}
Requires:       tcl-devel
Requires:       tk-devel

%description devel
This are the header files needed to develop a %{name} application.

%prep
%setup -q -n Img-%{version}-Source
%patch0 -p1 -b .CVE-2022-4645

%build
export CFLAGS="%{build_cflags} -lm"
%configure --with-tcl=%{tcl_sitearch} --with-tk=%{_libdir} --libdir=%{tcl_sitearch} --enable-64bit
%make_build

%install
%make_install INSTALL_ROOT=%{buildroot}

# Fixing some permissions
find %{buildroot}/%{tcl_sitearch} -name "*.sh" |xargs chmod 644
find %{buildroot}/%{tcl_sitearch} -name "*.tcl" |xargs chmod 644
find %{buildroot}/%{tcl_sitearch} -name "*.a" |xargs chmod 644
find %{buildroot}/%{tcl_sitearch} -name "*.so" |xargs chmod 755

# Make library links
%{__mv} %{buildroot}/%{tcl_sitearch}/*.sh %{buildroot}/%{_libdir}
for tcllibs in %{buildroot}/%{tcl_sitearch}/Img%{version}/*tcl*.so; do
btcllibs=`basename $tcllibs`
%{__ln_s} tcl%{tcl_version}/Img%{version}/$btcllibs %{buildroot}/%{_libdir}/$btcllibs
done

%files
%doc README
%license license.terms
%{_libdir}/*.so
%{tcl_sitearch}/Img%{version}
%exclude %{tcl_sitearch}/Img*/*.a
%{_mandir}/mann/img*

%files devel
%doc README
%{_includedir}/*
%{_libdir}/*.sh
%{tcl_sitearch}/Img%{version}/*.a


%changelog
* Tue Mar 07 2023 daviddavid <daviddavid> 1.4.14-2.mga9
+ Revision: 1948326
- apply upstream libtiff fix for CVE-2022-4645

* Sat Dec 03 2022 squidf <squidf> 1.4.14-1.mga9
+ Revision: 1916134
- Add -lm flag to pass ld step
- Use bundled libs
- Update patches
- Update source name
- New version: 1.4.14

* Tue Mar 29 2022 umeabot <umeabot> 1.4-11.mga9
+ Revision: 1831808
- Mageia 9 Mass Rebuild

* Mon Jul 06 2020 joequant <joequant> 1.4-10.mga8
+ Revision: 1602552
- build gcc10 patch
+ danf <danf>
- Switch URLs from http: to https:

* Fri Feb 14 2020 umeabot <umeabot> 1.4-9.mga8
+ Revision: 1517430
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sun Sep 23 2018 umeabot <umeabot> 1.4-8.mga7
+ Revision: 1301426
- Mageia 7 Mass Rebuild

* Wed Feb 17 2016 umeabot <umeabot> 1.4-7.mga6
+ Revision: 963073
- Mageia 6 Mass Rebuild

* Wed Nov 11 2015 daviddavid <daviddavid> 1.4-6.mga6
+ Revision: 902642
- rebuild for tcl/tk 8.6.4

* Sat May 02 2015 shlomif <shlomif> 1.4-5.mga5
+ Revision: 821046
- Fix PNG handling by incorporating some patches from Fedora.
- Should fix MGA#12596 - "Failure of some image handlers".

* Wed Oct 15 2014 umeabot <umeabot> 1.4-4.mga5
+ Revision: 750649
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.4-3.mga5
+ Revision: 689905
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 1.4-2.mga4
+ Revision: 531269
- Mageia 4 Mass Rebuild

* Fri Aug 02 2013 joequant <joequant> 1.4-1.mga4
+ Revision: 462738
- add tcllib
- update tkimg
+ dams <dams>
- new version 1.4
- clean specfile
- imported package tkimg


* Fri Dec 05 2008 Adam Williamson <awilliamson@mandriva.org> 1.4-0.20081115.1mdv2009.1
+ Revision: 310145
- import tkimg


